@@ -1,3 +1,5 @@
+from pathlib import Path
+
 from sportrefpy.nba.league import NBA
 from sportrefpy.nba.team import NBAFranchise
 
@@ -7,7 +9,7 @@ def all_players():
         for team in nba.teams.keys():
             franchise = NBAFranchise(team)
             players.update(franchise.players_all_time_stats().index)
-        with open('sportrefpy/assets/nba_players.txt', 'w', encoding='ascii') as file:
+        with open(Path(__file__).parent / 'sportrefpy/assets/nba_players.txt', 'w', encoding='ascii') as file:
             for player in players:
                 try:
                     file.write(f'{player}\n')
